@@ -1,10 +1,10 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2016, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef DRUMSTICK_MACROS_H
@@ -25,15 +24,13 @@
 /**
  * @file macros.h
  * Drumstick visibility macros
- * @defgroup Common Common Functionality
- * @{
  */
 
 #if !defined(DRUMSTICK_EXPORT) 
 #  if defined(DRUMSTICK_STATIC)
 #    define DRUMSTICK_EXPORT
 #  else
-#    if defined(drumstick_alsa_EXPORTS) || defined(drumstick_file_EXPORTS) || defined(drumstick_rt_EXPORTS)
+#    if defined(drumstick_alsa_EXPORTS) || defined(drumstick_file_EXPORTS) || defined(drumstick_rt_EXPORTS) || defined(drumstick_widgets_EXPORTS)
 #      define DRUMSTICK_EXPORT Q_DECL_EXPORT
 #    else
 #      if defined(Q_OS_WIN)
@@ -45,6 +42,4 @@
 #  endif
 #endif
 
-/** @} */
-
 #endif /* DRUMSTICK_MACROS_H */
